const {
	      gi  : {
		      Gtk: { Label, Switch, Box, Grid, Separator, Button },
		      GLib
	      },
	      misc: { extensionUtils }
      } = imports;
const _ = extensionUtils.gettext;

function init()
{
	extensionUtils.initTranslations();
}

function buildPrefsWidget()
{
	const me            = extensionUtils.getCurrentExtension();
	const { common }    = me.imports;
	const myCpuType     = common.getMyCpuType();
	const grid          = new Grid( {
		margin_top   : 24,
		margin_bottom: 24,
		margin_start : 24,
		margin_end   : 24,
		row_spacing  : 16,
		visible      : true
	} );
	const cpuSupportBox = new Box( { spacing: 8 } );
	let cpuSupportLabel = _( 'Sorry, your CPU is NOT supported!' );

	if ( myCpuType !== common.CPU_NOT_SUPPORTED )
	{
		cpuSupportLabel = _( 'Supported {{VENDOR}} CPU detected!' ).replace( '{{VENDOR}}', myCpuType === common.CPU_INTEL ? 'Intel' : 'AMD' );
	}

	cpuSupportBox.append( new Label( { label: cpuSupportLabel } ) );

	grid.attach( cpuSupportBox, 0, 0, 1, 1 );

	if ( myCpuType !== common.CPU_NOT_SUPPORTED )
	{
		const settings         = extensionUtils.getSettings();
		const settingSwitch    = new Switch( { active: settings.get_boolean( 'persist' ) } );
		const settingSwitchBox = new Box( { spacing: 8 } );
		const settinsButtonBox = new Box( { spacing: 8 } );
		const addButton        = new Button( { label: _( 'Add Rules' ) } );
		const removeButton     = new Button( { label: _( 'Remove Rules' ) } );

		addButton.connect( 'clicked', () => GLib.spawn_command_line_async( `pkexec bash -c "cp ${me.dir.get_child( 'freq-boost-switch.rules' ).get_path()} /etc/polkit-1/rules.d/"` ) );
		removeButton.connect( 'clicked', () => GLib.spawn_command_line_async( `pkexec bash -c "rm -f /etc/polkit-1/rules.d/freq-boost-switch.rules"` ) );

		settingSwitch.connect( 'notify::active', ( { active } ) => settings.set_boolean( 'persist', active ) );

		settingSwitchBox.append( new Label( { label: _( 'Persist' ) } ) );
		settingSwitchBox.append( settingSwitch );

		settinsButtonBox.append( addButton );
		settinsButtonBox.append( removeButton );

		grid.attach( new Separator, 0, 1, 1, 1 );
		grid.attach( settingSwitchBox, 0, 2, 1, 1 );
		grid.attach( new Label( { label: _( 'Warning! This will make permissions dialog to appear 5s after login (only if boost\nneeds to be changed).' ) } ), 0, 3, 1, 1 );
		grid.attach( new Separator, 0, 4, 1, 1 );
		grid.attach( new Label( { label: _( 'You can get rid of the permissions dialog by adding rules to the Polkit. By clicking\nthose buttons you will add/remove /etc/polkit-1/rules.d/freq-boost-switch.rules' ) } ), 0, 5, 1, 1 );
		grid.attach( settinsButtonBox, 0, 6, 1, 1 );
	}

	grid.show();

	return grid;
}